(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9583,        284]*)
(*NotebookOutlinePosition[     10393,        314]*)
(*  CellTagsIndexPosition[     10323,        308]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Tear-Off Styles", "Section"],

Cell[CellGroupData[{

Cell["\<\
Paul Wellin (wellin@wolfram.com)
Wolfram Education Group
Wolfram Research\
\>", "Subsubtitle"],

Cell["\<\
This utility can be used to create a palette of any set of cell \
styles from any style sheet. The palette can then be used to quickly set \
cells to a given style simply by clicking a button.\
\>", "Text"],

Cell["\<\
First create a path to the style sheet that you want to work \
with.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(styleSheet = 
      ToFileName[{$BaseDirectory, "\<Applications\>", "\<IPM3\>", "\<FrontEnd\
\>", "\<StyleSheets\>"}, "\<IPM3Styles.nb\>"]\)], "Input"],

Cell[BoxData[
    \("C:\\Documents and Settings\\All Users\\Application \
Data\\Mathematica\\Applications\\IPM3\\FrontEnd\\StyleSheets\\IPM3Styles.nb"\)\
], "Output"]
}, Open  ]],

Cell[TextData[{
  "Get all the cell styles which do not have a ",
  StyleBox["StyleMenuListing\[Rule]None", "MR"],
  " setting. These will typically be all those that you use regularly, but \
below we will edit that list also."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(menuStyleNames = \[IndentingNewLine]Cases[Get[styleSheet], 
        Cell[StyleData[s_String], opts___] \[RuleDelayed] 
          s /; \(! MemberQ[{opts}, 
                StyleMenuListing \[Rule] None]\), \[Infinity]]\)], "Input"],

Cell[BoxData[
    \({"Chapter", "Section", "Subsection", "Text", "TextFirst", 
      "BulletedList", "ItemizedText", "BulletedSubItem", "Editorial", 
      "DisplayTable", "Picture", "NonPrintSection", "NonPrintInput", 
      "NumberedEquation", "NumberedFigure", "NumberedTable", 
      "ProgramListing", "Input", "Output", "TermDefinition", "InlineFormula", 
      "DisplayFormula", "Program", "ContentsTitle", "IndexSubentry", 
      "RuledPageBreak", "TOCTitle", "TOCSection", "TOCSubsection", 
      "TOCSubsubsection", "TOCTitleDingbat", "TOCSectionDingbat", 
      "TOCSubsectionDingbat", "TitlePageGraphic", "TitlePageLogo", 
      "ExerciseSubsection", "ExerciseItem", "ExerciseSubItem", 
      "ExercisesNoLabel", "ExerciseItemNumber", "ExerciseSubItemNumber", 
      "SolutionsSection", "SolutionsSubsection", "SolutionItem", 
      "SolutionNoLabel"}\)], "Output"]
}, Open  ]],

Cell["\<\
Here I am explicitly tossing out some styles that I don't want on \
my palette. (I could later create a separate palette for all cell styles that \
deal with exercises say.) This is a long list and includes duplicates due to \
the different environments.\
\>", "Text"],

Cell[BoxData[
    \(Map[
      DeleteCases[
          menuStyleNames, #] &, {"\<ExerciseSubsection\>", \
"\<ExerciseItem\>", "\<ExercisesNoLabel\>", "\<ExerciseItemNumber\>", \
"\<SolutionsSubsection\>", "\<SolutionItem\>", "\<SolutionNoLabel\>", \
"\<InlineFormula\>", "\<ContentsTitle\>", "\<IndexSubentry\>", \
"\<TOCTitle\>", "\<TOCSection\>", "\<TOCSubsection\>", \
"\<TOCSubsubsection\>", "\<TOCTitleDingbat\>", "\<TOCSectionDingbat\>", \
"\<TOCSubsectionDingbat\>", "\<TOCTitleCondensed\>", \
"\<TOCSectionCondensed\>", "\<TOCSubsectionCondensed\>", \
"\<TOCSubsubsectionCondensed\>"}]\)], "Input"],

Cell["Get rid of the duplicates.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(menuStyleNames = Apply[Intersection, %]\)], "Input"],

Cell[BoxData[
    \({"BulletedList", "BulletedSubItem", "Chapter", "DisplayFormula", 
      "DisplayTable", "Editorial", "ExerciseSubItem", 
      "ExerciseSubItemNumber", "Input", "ItemizedText", "NonPrintInput", 
      "NonPrintSection", "NumberedEquation", "NumberedFigure", 
      "NumberedTable", "Output", "Picture", "Program", "ProgramListing", 
      "RuledPageBreak", "Section", "SolutionsSection", "Subsection", 
      "TermDefinition", "Text", "TextFirst", "TitlePageGraphic", 
      "TitlePageLogo"}\)], "Output"]
}, Open  ]],

Cell["\<\
Here is the code to make a palette out of the list of cell \
styles.\
\>", "Text"],

Cell[BoxData[
    \(styleButtonCell[lis_] := \[IndentingNewLine]Cell[
        BoxData[GridBox[\({ButtonBox[#, 
                    ButtonData \[RuleDelayed] #]} &\)\  /@ \ 
              lis, \[IndentingNewLine]RowSpacings\  \[Rule] \ 
              0, \[IndentingNewLine]ColumnSpacings\  \[Rule] \ 
              0]], \[IndentingNewLine]"\<Text\>", \[IndentingNewLine]CellTags\
\  \[Rule] \ "\<grid\>", \[IndentingNewLine]ButtonBoxOptions\  \[Rule] \ {\
\[IndentingNewLine]ButtonEvaluator\  \[Rule] \ 
              None, \[IndentingNewLine]ButtonFunction \[RuleDelayed] \
\((FrontEndExecute[{\[IndentingNewLine]FrontEndToken[
                        InputNotebook[], "\<Style\>", #2]}] &)\)\
\[IndentingNewLine]}]\)], "Input"],

Cell["Create the palette from the given list of style items.", "Text"],

Cell[BoxData[
    \(styleButtonCell[menuStyleNames] // CellPrint\)], "Input"],

Cell[BoxData[GridBox[{
        {
          ButtonBox["BulletedList",
            ButtonData:>"BulletedList"]},
        {
          ButtonBox["BulletedSubItem",
            ButtonData:>"BulletedSubItem"]},
        {
          ButtonBox["Chapter",
            ButtonData:>"Chapter"]},
        {
          ButtonBox["DisplayFormula",
            ButtonData:>"DisplayFormula"]},
        {
          ButtonBox["DisplayTable",
            ButtonData:>"DisplayTable"]},
        {
          ButtonBox["Editorial",
            ButtonData:>"Editorial"]},
        {
          ButtonBox["ExerciseSubItem",
            ButtonData:>"ExerciseSubItem"]},
        {
          ButtonBox["ExerciseSubItemNumber",
            ButtonData:>"ExerciseSubItemNumber"]},
        {
          ButtonBox["Input",
            ButtonData:>"Input"]},
        {
          ButtonBox["ItemizedText",
            ButtonData:>"ItemizedText"]},
        {
          ButtonBox["NonPrintInput",
            ButtonData:>"NonPrintInput"]},
        {
          ButtonBox["NonPrintSection",
            ButtonData:>"NonPrintSection"]},
        {
          ButtonBox["NumberedEquation",
            ButtonData:>"NumberedEquation"]},
        {
          ButtonBox["NumberedFigure",
            ButtonData:>"NumberedFigure"]},
        {
          ButtonBox["NumberedTable",
            ButtonData:>"NumberedTable"]},
        {
          ButtonBox["Output",
            ButtonData:>"Output"]},
        {
          ButtonBox["Picture",
            ButtonData:>"Picture"]},
        {
          ButtonBox["Program",
            ButtonData:>"Program"]},
        {
          ButtonBox["ProgramListing",
            ButtonData:>"ProgramListing"]},
        {
          ButtonBox["RuledPageBreak",
            ButtonData:>"RuledPageBreak"]},
        {
          ButtonBox["Section",
            ButtonData:>"Section"]},
        {
          ButtonBox["SolutionsSection",
            ButtonData:>"SolutionsSection"]},
        {
          ButtonBox["Subsection",
            ButtonData:>"Subsection"]},
        {
          ButtonBox["TermDefinition",
            ButtonData:>"TermDefinition"]},
        {
          ButtonBox["Text",
            ButtonData:>"Text"]},
        {
          ButtonBox["TextFirst",
            ButtonData:>"TextFirst"]},
        {
          ButtonBox["TitlePageGraphic",
            ButtonData:>"TitlePageGraphic"]},
        {
          ButtonBox["TitlePageLogo",
            ButtonData:>"TitlePageLogo"]}
        },
      RowSpacings->0,
      ColumnSpacings->0]], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEndToken[ 
        InputNotebook[ ], "Style", #2]}]&),
  ButtonEvaluator->None},
  CellTags->"grid"],

Cell["\<\
Generate a standalone palette. Make sure to save it \
afterwards.\
\>", "Text"],

Cell[BoxData[{
    \(\(NotebookLocate["\<grid\>"];\)\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<GeneratePalette\>"]\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
WindowSize->{659, 644},
WindowMargins->{{152, Automatic}, {Automatic, -2}},
Magnification->1.25,
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "grid"->{
    Cell[6569, 178, 2760, 94, 601, "Text",
      CellTags->"grid"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"grid", 10229, 301}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 34, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[1813, 55, 104, 4, 87, "Subsubtitle"],
Cell[1920, 61, 216, 4, 59, "Text"],
Cell[2139, 67, 92, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[2256, 74, 171, 3, 77, "Input"],
Cell[2430, 79, 166, 3, 77, "Output"]
}, Open  ]],
Cell[2611, 85, 239, 5, 59, "Text"],

Cell[CellGroupData[{
Cell[2875, 94, 250, 4, 98, "Input"],
Cell[3128, 100, 876, 13, 308, "Output"]
}, Open  ]],
Cell[4019, 116, 278, 5, 80, "Text"],
Cell[4300, 123, 605, 11, 224, "Input"],
Cell[4908, 136, 42, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[4975, 140, 72, 1, 35, "Input"],
Cell[5050, 143, 525, 8, 182, "Output"]
}, Open  ]],
Cell[5590, 154, 92, 3, 38, "Text"],
Cell[5685, 159, 728, 12, 266, "Input"],
Cell[6416, 173, 70, 0, 38, "Text"],
Cell[6489, 175, 77, 1, 35, "Input"],
Cell[6569, 178, 2760, 94, 601, "Text",
  CellTags->"grid"],
Cell[9332, 274, 89, 3, 38, "Text"],
Cell[9424, 279, 143, 2, 56, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

